# stubs/cross_crypto_py/core.pyi
from __future__ import annotations
from typing import TypedDict, Dict, Any, List

class CoreMetadata(TypedDict):
    filename: str
    mime: str
    size: int
    sha256: str

def create_zip_from_paths(paths: List[str], output_zip_path: str) -> str: ...
def extract_zip_to_dir(zip_path: str, output_dir: str) -> None: ...
def read_binary_file(path: str) -> bytes: ...
def write_binary_file(path: str, data: bytes) -> None: ...
def detect_mime_type(path: str) -> str: ...
def hash_file(path: str) -> str: ...
def collect_metadata(path: str) -> CoreMetadata: ...
def save_encrypted_json(output_path: str, encrypted_obj: Dict[str, Any]) -> None: ...
def load_encrypted_json(path: str) -> Dict[str, Any]: ...
